@@ -78,7 +78,7 @@ ln -s "${bprefix}/version.h" headers/aqbanking/version.h
 ln -s "${bprefix}/system.h" headers/aqbanking/system.h
 
 # symlink all headers from src/frontends
-dirlist=' qbanking'  # list might be empty
+dirlist='q4banking qbanking'  # list might be empty
 for frontend in ${dirlist} ; do
   mkdir -p headers/${frontend}
   symlinkFolder "src/frontends/${frontend}" "headers/${frontend}"
