@@ -135,16 +135,26 @@ QBImporter::QBImporter(QBanking *kb,
 
 QBImporter::~QBImporter(){
   AB_ImExporterContext_free(_context);
+  GWEN_DB_Group_free(_dbData);
+  _dbData=NULL;
 }
 
 
 bool QBImporter::init() {
-  GWEN_DB_NODE *db;
+  int rv;
+
+  GWEN_DB_Group_free(_dbData);
+  _dbData=NULL;
+
+  rv=_app->loadSharedSubConfig("qbanking",
+			       "gui/dlgs/importer",
+			       &_dbData,
+			       0);
+  if (rv<0) {
+    DBG_INFO(0, "Could not load shared config");
+    return false;
+  }
 
-  db=_app->getSharedData("qbanking");
-  assert(db);
-  _dbData=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-			   "gui/dlgs/importer");
   return _updateImporterList();
 }
 
@@ -173,6 +183,8 @@ void QBImporter::save() {
 
 
 bool QBImporter::fini() {
+  int rv;
+
   if (_importerList)
     GWEN_PluginDescription_List2_freeAll(_importerList);
   _importerList=0;
@@ -181,6 +193,17 @@ bool QBImporter::fini() {
   _profiles=0;
   _profile=0;
 
+  rv=_app->saveSharedSubConfig("qbanking",
+			       "gui/dlgs/importer",
+			       _dbData,
+			       0);
+  if (rv<0) {
+    DBG_INFO(0, "here (%d)", rv);
+  }
+
+  GWEN_DB_Group_free(_dbData);
+  _dbData=NULL;
+
   return true;
 }
 
@@ -850,7 +873,9 @@ bool QBImporter::_readFile(const QString &fname){
     // conversion operator "QCString::operator const char * ()
     // const" that will correctly convert the QCString to the
     // const char*
-    fd=open(fname.local8Bit().data(), O_RDONLY);
+    fd = ::open(fname.local8Bit().data(), O_RDONLY);
+    // Note: We need to write ::open() to avoid an ambiguity with
+    // QDialog::open().
     if (fd==-1) {
       qs=QWidget::tr("Could not open file \"%1\": %2")
 	.arg(fname)
