@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbmapaccount.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbmapaccount.h,v 1.6 2006/01/23 16:31:00 aquamaniac Exp $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
