@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qbprintdialog.cpp 837 2006-01-23 16:31:01Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -22,7 +22,7 @@
 // Gwenhywfar includes
 #include <gwenhywfar/text.h>
 #include <gwenhywfar/debug.h>
-#include <gwenhywfar/waitcallback.h>
+#include <gwenhywfar/gui.h>
 
 // QT includes
 #include <qlabel.h>
@@ -53,7 +53,6 @@ QBPrintDialog::QBPrintDialog(QBanking *app,
 ,_docType(docType)
 ,_descr(descr)
 ,_text(text)
-,_printer(new QPrinter(QPrinter::PrinterResolution))
 ,_fontFamily("Arial")
 ,_fontSize(11)
 ,_fontWeight(QFont::Normal)
@@ -75,7 +74,6 @@ QBPrintDialog::QBPrintDialog(QBanking *app,
                    this, SLOT(slotHelpClicked()));
 
   loadGuiSetup();
-  loadPrinterSetup();
 
   DBG_ERROR(0, "Setting text...");
   textBrowser->setText(QString::fromUtf8(text));
@@ -92,42 +90,46 @@ QBPrintDialog::~QBPrintDialog(){
 
 
 void QBPrintDialog::loadGuiSetup(){
-  GWEN_DB_NODE *db;
-  GWEN_BUFFER *dbuf;
-  int x, y;
+  GWEN_DB_NODE *dbConfig=NULL;
+  int rv;
 
-  db=_banking->getSharedData("qbanking");
-  assert(db);
-
-  db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                      "gui/dlgs/printdialog");
-  if (!db)
-    return;
-  dbuf=GWEN_Buffer_new(0, 64, 0, 1);
-  if (GWEN_Text_EscapeToBuffer(_docType, dbuf)) {
-    DBG_ERROR(0, "Internal error.");
-    abort();
+  rv=_banking->loadSharedSubConfig("qbanking",
+				   "gui/dlgs/printdialog",
+				   &dbConfig,
+				   0);
+  if (rv<0) {
+    DBG_INFO(0, "Could not load shared config");
   }
-  db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                      GWEN_Buffer_GetStart(dbuf));
-  GWEN_Buffer_free(dbuf);
-  if (!db)
-    return;
-  db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                      "gui");
-  if (!db)
-    return;
+  else {
+    GWEN_DB_NODE *db;
+    GWEN_BUFFER *dbuf;
 
-  x=GWEN_DB_GetIntValue(db, "width", 0, -1);
-  y=GWEN_DB_GetIntValue(db, "height", 0, -1);
-  if (x!=-1 && y!=-1) {
-    DBG_ERROR(0, "Resizing to %d/%d", x, y);
-    resize(x, y);
+    dbuf=GWEN_Buffer_new(0, 64, 0, 1);
+    if (GWEN_Text_EscapeToBuffer(_docType, dbuf)) {
+      DBG_ERROR(0, "Internal error.");
+      abort();
+    }
+    db=GWEN_DB_GetGroup(dbConfig, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+			GWEN_Buffer_GetStart(dbuf));
+    GWEN_Buffer_free(dbuf);
+    if (db) {
+      db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+			  "gui");
+      if (db) {
+	int x, y;
+
+	x=GWEN_DB_GetIntValue(db, "width", 0, -1);
+	y=GWEN_DB_GetIntValue(db, "height", 0, -1);
+	if (x!=-1 && y!=-1)
+	  resize(x, y);
+	x=GWEN_DB_GetIntValue(db, "x", 0, -1);
+	y=GWEN_DB_GetIntValue(db, "y", 0, -1);
+	if (x!=-1 && y!=-1)
+	  move(x, y);
+      }
+    }
+    GWEN_DB_Group_free(dbConfig);
   }
-  x=GWEN_DB_GetIntValue(db, "x", 0, -1);
-  y=GWEN_DB_GetIntValue(db, "y", 0, -1);
-  if (x!=-1 && y!=-1)
-    move(x, y);
 }
 
 
@@ -135,226 +137,221 @@ void QBPrintDialog::loadGuiSetup(){
 void QBPrintDialog::saveGuiSetup(){
   GWEN_DB_NODE *db;
   GWEN_BUFFER *dbuf;
+  int rv;
 
-  db=_banking->getSharedData("qbanking");
+  db=GWEN_DB_Group_new("config");
   assert(db);
 
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-                      "gui/dlgs/printdialog");
-  assert(db);
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		      "x", x());
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		      "y", y());
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		      "width", width());
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		      "height", height());
+
+  /* save config */
   dbuf=GWEN_Buffer_new(0, 64, 0, 1);
+  GWEN_Buffer_AppendString(dbuf, "gui/dlgs/printdialog/");
   if (GWEN_Text_EscapeToBuffer(_docType, dbuf)) {
     DBG_ERROR(0, "Internal error.");
     abort();
   }
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-                      GWEN_Buffer_GetStart(dbuf));
-  assert(db);
+  GWEN_Buffer_AppendString(dbuf, "/gui");
+
+  rv=_banking->saveSharedSubConfig("qbanking",
+				   GWEN_Buffer_GetStart(dbuf),
+				   db,
+				   0);
   GWEN_Buffer_free(dbuf);
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_OVERWRITE_GROUPS,
-                      "gui");
-  assert(db);
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                      "x", x());
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                      "y", y());
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                      "width", width());
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                      "height", height());
+  if (rv<0) {
+    DBG_INFO(0, "here (%d)", rv);
+  }
+  GWEN_DB_Group_free(db);
 }
 
 
 
-void QBPrintDialog::loadPrinterSetup(){
-  GWEN_DB_NODE *db;
-  GWEN_BUFFER *dbuf;
-  const char *s;
-  uint top, left, bottom, right;
-  int i;
+void QBPrintDialog::loadPrinterSetup(QPrinter *printer){
+  GWEN_DB_NODE *dbConfig=NULL;
+  int rv;
 
-  db=_banking->getSharedData("qbanking");
-  assert(db);
-
-  db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                      "gui/dlgs/printdialog");
-  if (!db)
-    return;
-  dbuf=GWEN_Buffer_new(0, 64, 0, 1);
-  if (GWEN_Text_EscapeToBuffer(_docType, dbuf)) {
-    DBG_ERROR(0, "Internal error.");
-    abort();
+  rv=_banking->loadSharedSubConfig("qbanking",
+				   "gui/dlgs/printdialog",
+				   &dbConfig,
+				   0);
+  if (rv<0) {
+    DBG_INFO(0, "Could not load shared config");
   }
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-                      GWEN_Buffer_GetStart(dbuf));
-  GWEN_Buffer_free(dbuf);
-  if (!db)
-    return;
-  db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                      "printer");
-  if (!db)
-    return;
+  else {
+    GWEN_DB_NODE *db;
+    GWEN_BUFFER *dbuf;
 
-  s=GWEN_DB_GetCharValue(db, "FontFamily", 0, "Arial");
-  if (s)
-    _fontFamily=QString::fromUtf8(s);
-  _fontSize=GWEN_DB_GetIntValue(db, "FontSize", 0, 11);
-  _fontWeight=QFont::Normal;
-  s=GWEN_DB_GetCharValue(db, "FontWeight", 0, "Normal");
-  _fontWeight=QFont::Normal;
-  if (s) {
-    if (strcasecmp(s, "Light")==0)
-      _fontWeight=QFont::Light;
-    else if (strcasecmp(s, "Normal")==0)
-      _fontWeight=QFont::Normal;
-    else if (strcasecmp(s, "DemiBold")==0)
-      _fontWeight=QFont::DemiBold;
-    else if (strcasecmp(s, "Bold")==0)
-      _fontWeight=QFont::Bold;
-    else if (strcasecmp(s, "Black")==0)
-      _fontWeight=QFont::Black;
-    else {
-      DBG_WARN(0, "Unknown FontWeight \"%s\"", s);
+    dbuf=GWEN_Buffer_new(0, 64, 0, 1);
+    if (GWEN_Text_EscapeToBuffer(_docType, dbuf)) {
+      DBG_ERROR(0, "Internal error.");
+      abort();
     }
+    db=GWEN_DB_GetGroup(dbConfig, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+			GWEN_Buffer_GetStart(dbuf));
+    GWEN_Buffer_free(dbuf);
+    if (db) {
+      const char *s;
+      int i;
+      unsigned int top, left, bottom, right;
+
+      db=GWEN_DB_GetGroup(db,
+			  GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+			  "printer");
+      s=GWEN_DB_GetCharValue(db, "FontFamily", 0, "Arial");
+      if (s)
+	_fontFamily=QString::fromUtf8(s);
+      _fontSize=GWEN_DB_GetIntValue(db, "FontSize", 0, 11);
+      _fontWeight=QFont::Normal;
+      s=GWEN_DB_GetCharValue(db, "FontWeight", 0, "Normal");
+      _fontWeight=QFont::Normal;
+      if (s) {
+	if (strcasecmp(s, "Light")==0)
+	  _fontWeight=QFont::Light;
+	else if (strcasecmp(s, "Normal")==0)
+	  _fontWeight=QFont::Normal;
+	else if (strcasecmp(s, "DemiBold")==0)
+	  _fontWeight=QFont::DemiBold;
+	else if (strcasecmp(s, "Bold")==0)
+	  _fontWeight=QFont::Bold;
+	else if (strcasecmp(s, "Black")==0)
+	  _fontWeight=QFont::Black;
+	else {
+	  DBG_WARN(0, "Unknown FontWeight \"%s\"", s);
+	}
+      }
+      textBrowser->setFont(QFont(_fontFamily, _fontSize, _fontWeight));
+    
+      s=GWEN_DB_GetCharValue(db, "PageSize", 0, 0);
+      if (s) {
+	QPrinter::PageSize ps=QPrinter::A4;
+	bool doSet;
+    
+	doSet=true;
+    
+	if (strcasecmp(s, "A0")==0)
+	  ps=QPrinter::A0;
+	else if (strcasecmp(s, "A1")==0)
+	  ps=QPrinter::A1;
+	else if (strcasecmp(s, "A2")==0)
+	  ps=QPrinter::A2;
+	else if (strcasecmp(s, "A3")==0)
+	  ps=QPrinter::A3;
+	else if (strcasecmp(s, "A4")==0)
+	  ps=QPrinter::A4;
+	else if (strcasecmp(s, "A5")==0)
+	  ps=QPrinter::A5;
+	else if (strcasecmp(s, "A6")==0)
+	  ps=QPrinter::A6;
+	else if (strcasecmp(s, "A7")==0)
+	  ps=QPrinter::A7;
+	else if (strcasecmp(s, "A8")==0)
+	  ps=QPrinter::A8;
+	else if (strcasecmp(s, "A9")==0)
+	  ps=QPrinter::A9;
+	else if (strcasecmp(s, "B0")==0)
+	  ps=QPrinter::B0;
+	else if (strcasecmp(s, "B1")==0)
+	  ps=QPrinter::B1;
+	else if (strcasecmp(s, "B2")==0)
+	  ps=QPrinter::B2;
+	else if (strcasecmp(s, "B3")==0)
+	  ps=QPrinter::B3;
+	else if (strcasecmp(s, "B4")==0)
+	  ps=QPrinter::B4;
+	else if (strcasecmp(s, "B5")==0)
+	  ps=QPrinter::B5;
+	else if (strcasecmp(s, "B6")==0)
+	  ps=QPrinter::B6;
+	else if (strcasecmp(s, "B7")==0)
+	  ps=QPrinter::B7;
+	else if (strcasecmp(s, "B8")==0)
+	  ps=QPrinter::B8;
+	else if (strcasecmp(s, "B9")==0)
+	  ps=QPrinter::B9;
+	else if (strcasecmp(s, "B10")==0)
+	  ps=QPrinter::B10;
+	else if (strcasecmp(s, "C5E")==0)
+	  ps=QPrinter::C5E;
+	else if (strcasecmp(s, "DLE")==0)
+	  ps=QPrinter::DLE;
+	else if (strcasecmp(s, "Comm10E")==0)
+	  ps=QPrinter::Comm10E;
+	else if (strcasecmp(s, "Executive")==0)
+	  ps=QPrinter::Executive;
+	else if (strcasecmp(s, "Folio")==0)
+	  ps=QPrinter::Folio;
+	else if (strcasecmp(s, "Ledger")==0)
+	  ps=QPrinter::Ledger;
+	else if (strcasecmp(s, "Legal")==0)
+	  ps=QPrinter::Legal;
+	else if (strcasecmp(s, "Letter")==0)
+	  ps=QPrinter::Letter;
+	else if (strcasecmp(s, "Tabloid")==0)
+	  ps=QPrinter::Tabloid;
+	else
+	  doSet=false;
+    
+	if (doSet)
+	  printer->setPageSize(ps);
+      }
+    
+      s=GWEN_DB_GetCharValue(db, "Orientation", 0, 0);
+      if (s) {
+	if (strcasecmp(s, "Portrait")==0)
+	  printer->setOrientation(QPrinter::Portrait);
+	else if (strcasecmp(s, "LandScape")==0)
+	  printer->setOrientation(QPrinter::Landscape);
+      }
+    
+      i=GWEN_DB_GetIntValue(db, "Resolution", 0, -1);
+      if (i!=-1)
+	printer->setResolution(i);
+    
+      top=(uint)GWEN_DB_GetIntValue(db, "Top", 0, -1);
+      left=(uint)GWEN_DB_GetIntValue(db, "Left", 0, -1);
+      bottom=(uint)GWEN_DB_GetIntValue(db, "Bottom", 0, -1);
+      right=(uint)GWEN_DB_GetIntValue(db, "Right", 0, -1);
+    #if (QT_VERSION < 0x040000)
+      // the current Qt4 snapshots don't have QPrinter::setMargins
+      if (top!=(uint)-1 && left!=(uint)-1 && bottom!=(uint)-1 && right!=(uint)-1)
+	printer->setMargins(top, left, bottom, right);
+    #endif
+    
+      s=GWEN_DB_GetCharValue(db, "ColorMode", 0, 0);
+      if (s) {
+	if (strcasecmp(s, "Color")==0)
+	  printer->setColorMode(QPrinter::Color);
+	else if (strcasecmp(s, "GrayScale")==0)
+	  printer->setColorMode(QPrinter::GrayScale);
+      }
+    
+      s=GWEN_DB_GetCharValue(db, "outputFileName", 0, 0);
+      if (s)
+	printer->setOutputFileName(QString::fromUtf8(s));
+      printer->setOutputToFile(GWEN_DB_GetIntValue(db, "outputToFile", 0, 0));
+    }
+
+    GWEN_DB_Group_free(dbConfig);
   }
-  textBrowser->setFont(QFont(_fontFamily, _fontSize, _fontWeight));
-
-  s=GWEN_DB_GetCharValue(db, "PageSize", 0, 0);
-  if (s) {
-    QPrinter::PageSize ps=QPrinter::A4;
-    bool doSet;
-
-    doSet=true;
-
-    if (strcasecmp(s, "A0")==0)
-      ps=QPrinter::A0;
-    else if (strcasecmp(s, "A1")==0)
-      ps=QPrinter::A1;
-    else if (strcasecmp(s, "A2")==0)
-      ps=QPrinter::A2;
-    else if (strcasecmp(s, "A3")==0)
-      ps=QPrinter::A3;
-    else if (strcasecmp(s, "A4")==0)
-      ps=QPrinter::A4;
-    else if (strcasecmp(s, "A5")==0)
-      ps=QPrinter::A5;
-    else if (strcasecmp(s, "A6")==0)
-      ps=QPrinter::A6;
-    else if (strcasecmp(s, "A7")==0)
-      ps=QPrinter::A7;
-    else if (strcasecmp(s, "A8")==0)
-      ps=QPrinter::A8;
-    else if (strcasecmp(s, "A9")==0)
-      ps=QPrinter::A9;
-    else if (strcasecmp(s, "B0")==0)
-      ps=QPrinter::B0;
-    else if (strcasecmp(s, "B1")==0)
-      ps=QPrinter::B1;
-    else if (strcasecmp(s, "B2")==0)
-      ps=QPrinter::B2;
-    else if (strcasecmp(s, "B3")==0)
-      ps=QPrinter::B3;
-    else if (strcasecmp(s, "B4")==0)
-      ps=QPrinter::B4;
-    else if (strcasecmp(s, "B5")==0)
-      ps=QPrinter::B5;
-    else if (strcasecmp(s, "B6")==0)
-      ps=QPrinter::B6;
-    else if (strcasecmp(s, "B7")==0)
-      ps=QPrinter::B7;
-    else if (strcasecmp(s, "B8")==0)
-      ps=QPrinter::B8;
-    else if (strcasecmp(s, "B9")==0)
-      ps=QPrinter::B9;
-    else if (strcasecmp(s, "B10")==0)
-      ps=QPrinter::B10;
-    else if (strcasecmp(s, "C5E")==0)
-      ps=QPrinter::C5E;
-    else if (strcasecmp(s, "DLE")==0)
-      ps=QPrinter::DLE;
-    else if (strcasecmp(s, "Comm10E")==0)
-      ps=QPrinter::Comm10E;
-    else if (strcasecmp(s, "Executive")==0)
-      ps=QPrinter::Executive;
-    else if (strcasecmp(s, "Folio")==0)
-      ps=QPrinter::Folio;
-    else if (strcasecmp(s, "Ledger")==0)
-      ps=QPrinter::Ledger;
-    else if (strcasecmp(s, "Legal")==0)
-      ps=QPrinter::Legal;
-    else if (strcasecmp(s, "Letter")==0)
-      ps=QPrinter::Letter;
-    else if (strcasecmp(s, "Tabloid")==0)
-      ps=QPrinter::Tabloid;
-    else
-      doSet=false;
-
-    if (doSet)
-      _printer->setPageSize(ps);
-  }
-
-  s=GWEN_DB_GetCharValue(db, "Orientation", 0, 0);
-  if (s) {
-    if (strcasecmp(s, "Portrait")==0)
-      _printer->setOrientation(QPrinter::Portrait);
-    else if (strcasecmp(s, "LandScape")==0)
-      _printer->setOrientation(QPrinter::Landscape);
-  }
-
-  i=GWEN_DB_GetIntValue(db, "Resolution", 0, -1);
-  if (i!=-1)
-    _printer->setResolution(i);
-
-  top=(uint)GWEN_DB_GetIntValue(db, "Top", 0, -1);
-  left=(uint)GWEN_DB_GetIntValue(db, "Left", 0, -1);
-  bottom=(uint)GWEN_DB_GetIntValue(db, "Bottom", 0, -1);
-  right=(uint)GWEN_DB_GetIntValue(db, "Right", 0, -1);
-#if (QT_VERSION < 0x040000)
-  // the current Qt4 snapshots don't have QPrinter::setMargins
-  if (top!=(uint)-1 && left!=(uint)-1 && bottom!=(uint)-1 && right!=(uint)-1)
-    _printer->setMargins(top, left, bottom, right);
-#endif
-
-  s=GWEN_DB_GetCharValue(db, "ColorMode", 0, 0);
-  if (s) {
-    if (strcasecmp(s, "Color")==0)
-      _printer->setColorMode(QPrinter::Color);
-    else if (strcasecmp(s, "GrayScale")==0)
-      _printer->setColorMode(QPrinter::GrayScale);
-  }
-
-  s=GWEN_DB_GetCharValue(db, "outputFileName", 0, 0);
-  if (s)
-    _printer->setOutputFileName(QString::fromUtf8(s));
-  _printer->setOutputToFile(GWEN_DB_GetIntValue(db, "outputToFile", 0, 0));
-
 }
 
 
 
-void QBPrintDialog::savePrinterSetup() {
+void QBPrintDialog::savePrinterSetup(QPrinter *printer) {
   GWEN_DB_NODE *db;
   GWEN_BUFFER *dbuf;
+  int rv;
   const char *s;
-  uint top, left, bottom, right;
+  unsigned int top, left, bottom, right;
 
-  db=_banking->getSharedData("qbanking");
-  assert(db);
-
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-                      "gui/dlgs/printdialog");
-  assert(db);
-  dbuf=GWEN_Buffer_new(0, 64, 0, 1);
-  if (GWEN_Text_EscapeToBuffer(_docType, dbuf)) {
-    DBG_ERROR(0, "Internal error.");
-    abort();
-  }
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-                      GWEN_Buffer_GetStart(dbuf));
-  assert(db);
-  GWEN_Buffer_free(dbuf);
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_OVERWRITE_GROUPS,
-                      "printer");
+  db=GWEN_DB_Group_new("config");
   assert(db);
 
   if (!_fontFamily.isEmpty())
@@ -388,14 +385,14 @@ void QBPrintDialog::savePrinterSetup() {
     break;
   }
 
-  QPrinter::Orientation orient=_printer->orientation();
+  QPrinter::Orientation orient=printer->orientation();
   if (orient==QPrinter::Portrait)
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                          "orientation", "portrait");
   else if (orient==QPrinter::Landscape)
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                          "orientation", "landscape");
-  switch(_printer->pageSize()) {
+  switch(printer->pageSize()) {
   case QPrinter::A0: s="A0"; break;
   case QPrinter::A1: s="A1"; break;
   case QPrinter::A2: s="A2"; break;
@@ -438,14 +435,14 @@ void QBPrintDialog::savePrinterSetup() {
                          "PageSize", s);
 
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                      "Resolution", _printer->resolution());
-  _printer->margins(&top, &left, &bottom, &right);
+                      "Resolution", printer->resolution());
+  printer->margins(&top, &left, &bottom, &right);
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS, "Top", top);
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS, "Left", left);
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS, "Bottom", bottom);
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS, "Right", right);
 
-  switch(_printer->colorMode()) {
+  switch(printer->colorMode()) {
   case QPrinter::Color: s="Color"; break;
   case QPrinter::GrayScale: s="GrayScale"; break;
   default: s=0; break;
@@ -456,17 +453,34 @@ void QBPrintDialog::savePrinterSetup() {
 
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                       "outputToFile",
-                      (_printer->outputToFile())?1:0);
-  QString fname = _printer->outputFileName();
+                      (printer->outputToFile())?1:0);
+  QString fname = printer->outputFileName();
   if (!fname.isEmpty())
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                          "outputFileName", fname.utf8());
 
+  /* save config */
+  dbuf=GWEN_Buffer_new(0, 64, 0, 1);
+  GWEN_Buffer_AppendString(dbuf, "gui/dlgs/printdialog/");
+  if (GWEN_Text_EscapeToBuffer(_docType, dbuf)) {
+    DBG_ERROR(0, "Internal error.");
+    abort();
+  }
+  GWEN_Buffer_AppendString(dbuf, "/printer");
+
+  rv=_banking->saveSharedSubConfig("qbanking",
+				   GWEN_Buffer_GetStart(dbuf),
+				   db,
+				   0);
+  GWEN_Buffer_free(dbuf);
+  if (rv<0) {
+    DBG_INFO(0, "here (%d)", rv);
+  }
+  GWEN_DB_Group_free(db);
 }
 
 
 void QBPrintDialog::accept(){
-  savePrinterSetup();
   saveGuiSetup();
   QDialog::accept();
 }
@@ -474,7 +488,11 @@ void QBPrintDialog::accept(){
 
 
 void QBPrintDialog::slotSetup(){
-  _printer->setup();
+  QPrinter printer(QPrinter::PrinterResolution);
+
+  loadPrinterSetup(&printer);
+  printer.setup();
+  savePrinterSetup(&printer);
 }
 
 
@@ -498,15 +516,19 @@ void QBPrintDialog::slotFont() {
 
 
 void QBPrintDialog::slotPrint(){
-  QPainter p;
+  QPrinter printer(QPrinter::PrinterResolution);
+
   QFont fnt(_fontFamily, _fontSize, _fontWeight);
   int XMargin;
   int YMargin;
 
-  if (!p.begin(_printer)) {
+  loadPrinterSetup(&printer);
+
+  QPainter p(&printer);
+  if (!p.isActive()) {
     QMessageBox::critical(this,
-                          tr("Print"),
-                          tr("Printing aborted."),
+			  tr("Print"),
+			  tr("Printing aborted."),
 			  QMessageBox::Ok,QMessageBox::NoButton);
     return;
   }
@@ -515,7 +537,7 @@ void QBPrintDialog::slotPrint(){
 
   QPaintDeviceMetrics metrics(p.device());
   XMargin = 0; //(int)((2/2.54)*metrics.logicalDpiX()); // 2 cm margins
-  YMargin = 0; //(int)((2/2.54)*metrics.logicalDpiY()); // 2 cm margins
+  YMargin = 5; //(int)((2/2.54)*metrics.logicalDpiY()); // 2 cm margins
 
   QRect body(XMargin, YMargin,
              metrics.width() - 2*XMargin,
@@ -534,16 +556,11 @@ void QBPrintDialog::slotPrint(){
                               tr("Text does not fit on the page.\n"
                                  "Do you want to print it anyway?"),
 			      QMessageBox::Yes,QMessageBox::Abort);
-    if (r !=0 && r != QMessageBox::Yes)
+    if (r !=0 && r != QMessageBox::Yes) {
       return;
+    }
   }
 
-  GWEN_WaitCallback_EnterWithText(GWEN_WAITCALLBACK_ID_SIMPLE_PROGRESS,
-                                  tr("Printing, please wait...").utf8(),
-                                  tr("page(s)").utf8(),
-                                  0);
-  GWEN_WaitCallback_SetProgressTotal(GWEN_WAITCALLBACK_PROGRESS_NONE);
-
   QRect view(body);
   int page = 1;
   do {
@@ -554,25 +571,11 @@ void QBPrintDialog::slotPrint(){
     p.drawText(view.right() - p.fontMetrics().width(QString::number(page)),
                view.bottom() + p.fontMetrics().ascent() + 5,
                QString::number(page));
+    printer.newPage();
     if (view.top()>=txt.height())
       break;
-    _printer->newPage();
-    if (GWEN_WaitCallbackProgress(page)==
-        GWEN_WaitCallbackResult_Abort) {
-      int r = QMessageBox::critical(this,
-                                tr("Aborted"),
-                                tr("Do you really want to abort?"),
-				QMessageBox::Yes,QMessageBox::No);
-      if (r !=0 && r != QMessageBox::Yes) {
-        GWEN_WaitCallback_Leave();
-        return;
-      }
-    }
     page++;
   } while (TRUE);
-  GWEN_WaitCallback_Leave();
-
-  p.end();
 }
 
 
