@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qbprintdialog.h 837 2006-01-23 16:31:01Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -49,13 +49,12 @@ private:
   const char *_docType;
   const char *_descr;
   const char *_text;
-  QPrinter *_printer;
   QString _fontFamily;
   int _fontSize;
   int _fontWeight;
 
-  void loadPrinterSetup();
-  void savePrinterSetup();
+  void loadPrinterSetup(QPrinter *printer);
+  void savePrinterSetup(QPrinter *printer);
 
   void loadGuiSetup();
   void saveGuiSetup();
