@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: qbselectbackend.h 811 2006-01-20 14:52:36Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -18,7 +18,7 @@
 class QBanking;
 
 #include "qbselectbackend.ui.h"
-#include <qbanking/banking.h> /* For QBANKING_API */
+#include <qbanking/qbanking.h> /* For QBANKING_API */
 #include <string>
 
 
