@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: qbselectbank.cpp 837 2006-01-23 16:31:01Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -359,7 +359,7 @@ void QBSelectBank::accept() {
   else {
     QMessageBox::critical(this,
                           tr("Selection Error"),
-                          tr("No Bank Selected."),
+                          tr("No bank selected."),
 			  QMessageBox::Retry,QMessageBox::NoButton);
   }
 }
@@ -369,11 +369,13 @@ void QBSelectBank::accept() {
 void QBSelectBank::slotDoubleClicked(QListViewItem *lv,
                                    const QPoint &,
                                    int) {
-  bankCodeEdit->setText(lv->text(0));
-  bankNameEdit->setText(lv->text(1));
-  locationEdit->setText(lv->text(2));
-  swiftCodeEdit->setText(lv->text(3));
-  accept();
+  if (lv) {
+    bankCodeEdit->setText(lv->text(0));
+    bankNameEdit->setText(lv->text(1));
+    locationEdit->setText(lv->text(2));
+    swiftCodeEdit->setText(lv->text(3));
+    accept();
+  }
 }
 
 
