@@ -208,7 +208,7 @@ bool QBanking::setAccountStatus(const AB_ACCOUNT *a,
 AB_ACCOUNT *QBanking::_getAccount(const char *accountId){
   AB_ACCOUNT *a;
 
-  a=AB_Banking_GetAccountByAlias(getCInterface(), accountId);
+  a=AB_Banking_GetAccountByAlias(getCInterface(), accountId, 0);
   if (!a) {
     // should not happen anyway
     QMessageBox::critical(_parentWidget,
@@ -233,7 +233,7 @@ void QBanking::setAccountAlias(AB_ACCOUNT *a, const char *alias){
   assert(a);
   assert(alias);
 
-  AB_Banking_SetAccountAlias(getCInterface(), a, alias);
+  AB_Banking_SetAccountAlias(getCInterface(), a, alias, 0);
 }
 
 
@@ -690,10 +690,11 @@ int QBanking::print(const QString &docTitle,
                     const QString &docType,
                     const QString &descr,
                     const QString &text) {
-  return print(QStringToUtf8String(docTitle).c_str(),
-               QStringToUtf8String(docType).c_str(),
-               QStringToUtf8String(descr).c_str(),
-               QStringToUtf8String(text).c_str());
+  return GWEN_Gui_Print(QStringToUtf8String(docTitle).c_str(),
+			QStringToUtf8String(docType).c_str(),
+			QStringToUtf8String(descr).c_str(),
+			QStringToUtf8String(text).c_str(),
+			0);
 }
 
 
