@@ -570,6 +570,8 @@ void AB_Account_free(AB_ACCOUNT *a){
       free(a->ownerName);
       free(a->currency);
       free(a->country);
+      free(a->dbId);
+
       GWEN_StringList_free(a->userIds);
       GWEN_StringList_free(a->selectedUserIds);
 
@@ -634,29 +636,6 @@ AB_PROVIDER *AB_Account_GetProvider(const AB_ACCOUNT *a) {
 
 
 
-GWEN_DB_NODE *AB_Account_GetAppData(const AB_ACCOUNT *a){
-  GWEN_DB_NODE *n;
-  const char *appName;
-
-  assert(a);
-  assert(a->usage);
-  appName=AB_Banking_GetEscapedAppName(a->banking);
-  assert(appName);
-  n=GWEN_DB_GetGroup(a->appData, GWEN_DB_FLAGS_DEFAULT, appName);
-  return n;
-}
-
-
-
-GWEN_DB_NODE *AB_Account_GetProviderData(const AB_ACCOUNT *a){
-  assert(a);
-  assert(a->usage);
-
-  return a->providerData;
-}
-
-
-
 const char *AB_Account_GetAccountNumber(const AB_ACCOUNT *a){
   assert(a);
   assert(a->usage);
@@ -867,7 +846,6 @@ void AB_Account_SetCountry(AB_ACCOUNT *a, const char *s){
 
 
 
-
 void AB_Account_SetProvider(AB_ACCOUNT *a, AB_PROVIDER *pro){
   assert(a);
   assert(a->usage);
@@ -880,6 +858,26 @@ void AB_Account_SetProvider(AB_ACCOUNT *a, AB_PROVIDER *pro){
 
 
 
+const char *AB_Account_GetDbId(const AB_ACCOUNT *a) {
+  assert(a);
+  assert(a->usage);
+
+  return a->dbId;
+}
+
+
+
+void AB_Account_SetDbId(AB_ACCOUNT *a, const char *s) {
+  assert(a);
+  assert(a->usage);
+
+  free(a->dbId);
+  if (s) a->dbId=strdup(s);
+  else a->dbId=NULL;
+}
+
+
+
 AB_ACCOUNT *AB_Account__freeAll_cb(AB_ACCOUNT *a, void *userData) {
   AB_Account_free(a);
   return 0;
