@@ -53,7 +53,8 @@ typedef enum {
   AB_AccountType_Checking,
   AB_AccountType_Savings,
   AB_AccountType_Investment,
-  AB_AccountType_Cash
+  AB_AccountType_Cash,
+  AB_AccountType_MoneyMarket
 } AB_ACCOUNT_TYPE;
 
 #ifdef __cplusplus
@@ -95,11 +96,6 @@ const char *AB_Account_GetBackendName(const AB_ACCOUNT *acc);
 AQBANKING_API 
 AB_PROVIDER *AB_Account_GetProvider(const AB_ACCOUNT *acc);
 
-AQBANKING_API AQBANKING_DEPRECATED
-GWEN_DB_NODE *AB_Account_GetAppData(const AB_ACCOUNT *acc);
-AQBANKING_API AQBANKING_DEPRECATED
-GWEN_DB_NODE *AB_Account_GetProviderData(const AB_ACCOUNT *acc);
-
 AQBANKING_API 
 const char *AB_Account_GetAccountNumber(const AB_ACCOUNT *acc);
 AQBANKING_API 
@@ -188,8 +184,6 @@ AQBANKING_API
 void AB_Account_SetSelectedUser(AB_ACCOUNT *a, const AB_USER *u);
 
 
-
-
 #ifdef __cplusplus
 }
 #endif
