@@ -100,7 +100,7 @@ void AB_Provider_SetPlugin(AB_PROVIDER *pro, GWEN_PLUGIN *pl) {
 
 
 
-int AB_Provider_Init(AB_PROVIDER *pro){
+int AB_Provider_Init(AB_PROVIDER *pro, uint32_t guiid){
   assert(pro);
   if (pro->isInit) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Provider already is initialized");
@@ -108,40 +108,107 @@ int AB_Provider_Init(AB_PROVIDER *pro){
   }
   if (pro->initFn) {
     int rv;
-    GWEN_DB_NODE *dbData;
+    GWEN_DB_NODE *dbData=NULL;
 
-    dbData=AB_Banking_GetProviderData(pro->banking, pro);
-    assert(dbData);
+    rv=AB_Banking_LoadPluginConfig(pro->banking,
+				   AB_CFG_GROUP_BACKENDS,
+				   pro->name, &dbData,
+				   guiid);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+    else {
+      assert(dbData);
 
-    rv=pro->initFn(pro, dbData);
-    if (!rv)
-      pro->isInit=1;
-    return rv;
+      rv=pro->initFn(pro, dbData);
+      if (!rv)
+	pro->isInit=1;
+      GWEN_DB_Group_free(dbData);
+      return rv;
+    }
+  }
+  else {
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "No init function set");
+    return GWEN_ERROR_NOT_IMPLEMENTED;
   }
-  DBG_ERROR(AQBANKING_LOGDOMAIN, "No init function set");
-  return GWEN_ERROR_NOT_IMPLEMENTED;
 }
 
 
 
-int AB_Provider_Fini(AB_PROVIDER *pro){
+int AB_Provider_Fini(AB_PROVIDER *pro, uint32_t guiid){
   assert(pro);
   if (pro->isInit==0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Provider is not initialized");
     return GWEN_ERROR_INVALID;
   }
   if (pro->finiFn) {
+    int rv;
     GWEN_DB_NODE *dbData;
 
-    dbData=AB_Banking_GetProviderData(pro->banking, pro);
-    assert(dbData);
+    rv=AB_Banking_LockPluginConfig(pro->banking,
+                                   AB_CFG_GROUP_BACKENDS,
+				   pro->name,
+				   guiid);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+
+    rv=AB_Banking_LoadPluginConfig(pro->banking,
+                                   AB_CFG_GROUP_BACKENDS,
+				   pro->name, &dbData,
+				   guiid);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      AB_Banking_UnlockPluginConfig(pro->banking,
+                                    AB_CFG_GROUP_BACKENDS,
+				    pro->name,
+				    guiid);
+      return rv;
+    }
 
     pro->isInit=0;
-    return pro->finiFn(pro, dbData);
+    rv=pro->finiFn(pro, dbData);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      AB_Banking_UnlockPluginConfig(pro->banking,
+				    AB_CFG_GROUP_BACKENDS,
+				    pro->name,
+				    guiid);
+      GWEN_DB_Group_free(dbData);
+      return rv;
+    }
+
+    rv=AB_Banking_SavePluginConfig(pro->banking,
+				   AB_CFG_GROUP_BACKENDS,
+				   pro->name, dbData, guiid);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      AB_Banking_UnlockPluginConfig(pro->banking,
+				    AB_CFG_GROUP_BACKENDS,
+				    pro->name,
+				    guiid);
+      GWEN_DB_Group_free(dbData);
+      return rv;
+    }
+
+    rv=AB_Banking_UnlockPluginConfig(pro->banking,
+				     AB_CFG_GROUP_BACKENDS,
+				     pro->name, guiid);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      GWEN_DB_Group_free(dbData);
+      return rv;
+    }
+    GWEN_DB_Group_free(dbData);
+    return 0;
+  }
+  else {
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "No fini function set");
+    pro->isInit=0;
+    return GWEN_ERROR_NOT_IMPLEMENTED;
   }
-  DBG_ERROR(AQBANKING_LOGDOMAIN, "No fini function set");
-  pro->isInit=0;
-  return GWEN_ERROR_NOT_IMPLEMENTED;
 }
 
 
@@ -377,17 +444,6 @@ int AB_Provider_GetUserDataDir(const AB_PROVIDER *pro, GWEN_BUFFER *buf){
 
 
 
-GWEN_DB_NODE *AB_Provider_GetData(AB_PROVIDER *pro) {
-  assert(pro);
-  assert(pro->banking);
-  assert(pro->escName);
-
-  return AB_Banking_GetProviderData(pro->banking, pro);
-}
-
-
-
-
 GWEN_PLUGIN *AB_Plugin_Provider_new(GWEN_PLUGIN_MANAGER *pm,
 				    const char *name,
 				    const char *fileName) {
@@ -405,7 +461,7 @@ GWEN_PLUGIN *AB_Plugin_Provider_new(GWEN_PLUGIN_MANAGER *pm,
 
 
 
-void AB_Plugin_Provider_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB AB_Plugin_Provider_FreeData(void *bp, void *p) {
   AB_PLUGIN_PROVIDER *xpl;
 
   xpl=(AB_PLUGIN_PROVIDER*)p;
