@@ -60,51 +60,6 @@ AB_PROVIDER *AB_User_GetProvider(const AB_USER *u) {
 
 
 
-GWEN_DB_NODE *AB_User_GetProviderData(const AB_USER *u) {
-  GWEN_DB_NODE *db;
-  const char *s;
-  AB_PROVIDER *pro;
-
-  assert(u);
-  db=AB_User_GetData(u);
-  assert(db);
-
-  s=AB_User_GetBackendName(u);
-  assert(s);
-
-  pro=AB_Banking_GetProvider(u->banking, s);
-  assert(pro);
-
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT, "backend");
-  assert(db);
-
-  return db;
-}
-
-
-
-GWEN_DB_NODE *AB_User_GetAppData(const AB_USER *u) {
-  GWEN_DB_NODE *db;
-  const char *s;
-
-  assert(u);
-  db=AB_User_GetData(u);
-  assert(db);
-
-  s=AB_Banking_GetEscapedAppName(u->banking);
-  assert(s);
-
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT, "apps");
-  assert(db);
-
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT, s);
-  assert(db);
-
-  return db;
-}
-
-
-
 int AB_User__dbToDb(GWEN_DB_NODE *n, GWEN_DB_NODE *where) {
   return GWEN_DB_AddGroupChildren(where, n);
 }
