@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -20,6 +17,7 @@
 
 
 AB_USER *AB_User_new(AB_BANKING *ab);
+AB_USER *AB_User_fromDb(AB_BANKING *ab, GWEN_DB_NODE *db);
 int AB_User__dbToDb(GWEN_DB_NODE *n, GWEN_DB_NODE *where);
 
 
