@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: accountjob.c 764 2006-01-13 14:00:00Z cstim $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -83,7 +83,7 @@ AB_ACCOUNT *AH_AccountJob_GetAccount(const AH_JOB *j){
 
 
 /* --------------------------------------------------------------- FUNCTION */
-void AH_AccountJob_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB AH_AccountJob_FreeData(void *bp, void *p) {
   AH_ACCOUNTJOB *aj;
 
   aj=(AH_ACCOUNTJOB*)p;
