@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: jobgetbalance_p.h 950 2006-02-22 19:39:02Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -23,10 +23,13 @@ typedef struct AH_JOB_GETBALANCE AH_JOB_GETBALANCE;
 struct AH_JOB_GETBALANCE {
   int dummy;
 };
-static void AH_Job_GetBalance_FreeData(void *bp, void *p);
-static int AH_Job_GetBalance_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static void GWENHYWFAR_CB AH_Job_GetBalance_FreeData(void *bp, void *p);
+static int AH_Job_GetBalance_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				     uint32_t guiid);
 static int AH_Job_GetBalance_Exchange(AH_JOB *j, AB_JOB *bj,
-                                      AH_JOB_EXCHANGE_MODE m);
+				      AH_JOB_EXCHANGE_MODE m,
+				      AB_IMEXPORTER_CONTEXT *ctx,
+				      uint32_t guiid);
 
 static AB_BALANCE *AH_Job_GetBalance__ReadBalance(GWEN_DB_NODE *dbT);
 
