@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: jobsingletransfer_p.h 950 2006-02-22 19:39:02Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -25,11 +25,14 @@ struct AH_JOB_SINGLETRANSFER {
   char *fiid;
   char *oldFiid;
 };
-static void AH_Job_SingleTransfer_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AH_Job_SingleTransfer_FreeData(void *bp, void *p);
 static int AH_Job_SingleTransfer_Process(AH_JOB *j,
-                                         AB_IMEXPORTER_CONTEXT *ctx);
+					 AB_IMEXPORTER_CONTEXT *ctx,
+					 uint32_t guiid);
 static int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
-                                          AH_JOB_EXCHANGE_MODE m);
+					  AH_JOB_EXCHANGE_MODE m,
+					  AB_IMEXPORTER_CONTEXT *ctx,
+					  uint32_t guiid);
 
 
 static int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
