@@ -943,7 +943,7 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     }
   }
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Dialog open request done");
-  rv=AH_Job_CommitSystemData(jDlgOpen, guiid);
+  rv=AH_Job_CommitSystemData(jDlgOpen, 0, guiid);
   AH_JobQueue_free(jqDlgOpen);
   return rv;
 }
@@ -1006,7 +1006,7 @@ int AH_Outbox__CBox_CloseDialog(AH_OUTBOX__CBOX *cbox,
     return rv;
   }
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Dialog closed");
-  rv=AH_Job_CommitSystemData(jDlgClose, guiid);
+  rv=AH_Job_CommitSystemData(jDlgClose, 0, guiid);
   AH_JobQueue_free(jqDlgClose);
   if (rv) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Could not commit system data");
@@ -1367,8 +1367,8 @@ int AH_Outbox__CBox_SendAndRecvDialogQueues(AH_OUTBOX__CBOX *cbox,
     while((jq=AH_JobQueue_List_First(jqlWanted))) {
       rv=AH_Outbox__CBox_PerformDialogQueue(cbox, timeout, jq, guiid);
       if (rv) {
-	DBG_ERROR(AQHBCI_LOGDOMAIN,
-		  "Error performing queue (%d)", rv);
+	DBG_INFO(AQHBCI_LOGDOMAIN,
+		 "Error performing queue (%d)", rv);
         AH_Outbox__CBox_HandleQueueListError(cbox, jqlWanted,
                                              "Could not perform "
                                              "dialog queue");
@@ -1891,7 +1891,7 @@ AH_JOB_LIST *AH_Outbox_GetFinishedJobs(AH_OUTBOX *ob, uint32_t guiid){
 
 
 
-void AH_Outbox_Commit(AH_OUTBOX *ob, uint32_t guiid){
+void AH_Outbox_Commit(AH_OUTBOX *ob, int doLock, uint32_t guiid){
   AH_JOB *j;
 
   assert(ob);
@@ -1900,7 +1900,7 @@ void AH_Outbox_Commit(AH_OUTBOX *ob, uint32_t guiid){
     if (AH_Job_GetStatus(j)==AH_JobStatusAnswered) {
       /* only commit answered jobs */
       DBG_NOTICE(AQHBCI_LOGDOMAIN, "Committing job \"%s\"", AH_Job_GetName(j));
-      AH_Job_Commit(j, guiid);
+      AH_Job_Commit(j, doLock, guiid);
     }
     j=AH_Job_List_Next(j);
   } /* while */
@@ -1908,7 +1908,7 @@ void AH_Outbox_Commit(AH_OUTBOX *ob, uint32_t guiid){
 
 
 
-void AH_Outbox_CommitSystemData(AH_OUTBOX *ob, uint32_t guiid){
+void AH_Outbox_CommitSystemData(AH_OUTBOX *ob, int doLock, uint32_t guiid){
   AH_JOB *j;
 
   assert(ob);
@@ -1917,7 +1917,7 @@ void AH_Outbox_CommitSystemData(AH_OUTBOX *ob, uint32_t guiid){
     if (AH_Job_GetStatus(j)==AH_JobStatusAnswered) {
       /* only commit answered jobs */
       DBG_NOTICE(AQHBCI_LOGDOMAIN, "Committing job \"%s\"", AH_Job_GetName(j));
-      AH_Job_DefaultCommitHandler(j, guiid);
+      AH_Job_DefaultCommitHandler(j, doLock, guiid);
     }
     j=AH_Job_List_Next(j);
   } /* while */
