@@ -25,7 +25,6 @@ struct AH_PROVIDER {
   AH_HBCI *hbci;
   AB_JOB_LIST2 *bankingJobs;
   AH_OUTBOX *outbox;
-  GWEN_DB_NODE *dbConfig;
   GWEN_DB_NODE *dbTempConfig;
 };
 static void GWENHYWFAR_CB AH_Provider_FreeData(void *bp, void *p);
@@ -34,6 +33,7 @@ static void GWENHYWFAR_CB AH_Provider_FreeData(void *bp, void *p);
 static AH_JOB *AH_Provider__FindMyJob(AH_JOB_LIST *mjl, uint32_t jid);
 
 static int AH_Provider__HashRmd160(const uint8_t *p, unsigned int l, uint8_t *buf);
+static int AH_Provider__HashSha256(const uint8_t *p, unsigned int l, uint8_t *buf);
 
 
 /** @name Overwritten Virtual Functions
@@ -60,6 +60,32 @@ static int AH_Provider_Update(AB_PROVIDER *pro,
                               uint32_t lastVersion,
                               uint32_t currentVersion);
 
+static int AH_Provider_GetIniLetterTxt1(AB_PROVIDER *pro,
+					AB_USER *u,
+					int useBankKey,
+					GWEN_BUFFER *lbuf,
+					int nounmount,
+					uint32_t guiid);
+static int AH_Provider_GetIniLetterHtml1(AB_PROVIDER *pro,
+					 AB_USER *u,
+					 int useBankKey,
+					 GWEN_BUFFER *lbuf,
+					 int nounmount,
+					 uint32_t guiid);
+
+static int AH_Provider_GetIniLetterTxt2(AB_PROVIDER *pro,
+					AB_USER *u,
+					int useBankKey,
+					GWEN_BUFFER *lbuf,
+					int nounmount,
+					uint32_t guiid);
+static int AH_Provider_GetIniLetterHtml2(AB_PROVIDER *pro,
+					 AB_USER *u,
+					 int useBankKey,
+					 GWEN_BUFFER *lbuf,
+					 int nounmount,
+					 uint32_t guiid);
+
 /*@}*/
 
 #endif /* AH_PROVIDER_P_H */
