@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: bpd.c 410 2005-08-05 20:33:14Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -458,7 +458,7 @@ void AH_Bpd_SetIsDirty(AH_BPD *bpd, int dirty){
 
 
 void AH_Bpd_Dump(const AH_BPD *bpd, FILE *f, int insert) {
-  GWEN_TYPE_UINT32 k;
+  uint32_t k;
   unsigned int i;
 
   for (k=0; k<insert; k++)
