@@ -25,6 +25,8 @@
 #include <aqhbci/provider.h>
 #include "adminjobs_l.h"
 
+#include <aqbanking/banking_be.h>
+
 #include <gwenhywfar/debug.h>
 
 #include <stdlib.h>
@@ -161,16 +163,26 @@ void AH_User_Extend(AB_USER *u, AB_PROVIDER *pro,
       ue->hbciVersion=210;
       ue->bpd=AH_Bpd_new();
       ue->dbUpd=GWEN_DB_Group_new("upd");
+      ue->maxTransfersPerJob=AH_USER_MAX_TRANSFERS_PER_JOB;
+      ue->maxDebitNotesPerJob=AH_USER_MAX_DEBITNOTES_PER_JOB;
     }
     else {
       /* update db to latest version */
       rv=AH_HBCI_UpdateDbUser(ue->hbci, db);
-      if (rv) {
+      if (rv<0) {
 	DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not update user db (%d)", rv);
 	assert(0);
       }
       AH_User_ReadDb(u, db);
       AH_User_LoadTanMethods(u);
+      if (rv==1) {
+	/* updated config, write it now */
+	rv=AB_Banking_SaveUserConfig(AB_Provider_GetBanking(pro), u, 1);
+	if (rv<0) {
+	  DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not save user db (%d)", rv);
+	  assert(0);
+	}
+      }
     }
   }
   else if (em==AB_ProviderExtendMode_Reload) {
@@ -265,8 +277,9 @@ void AH_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db) {
   if (ue->dbUpd)
     GWEN_DB_Group_free(ue->dbUpd);
   gr=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "upd");
-  if (gr)
+  if (gr) {
     ue->dbUpd=GWEN_DB_Group_dup(gr);
+  }
   else
     ue->dbUpd=GWEN_DB_Group_new("upd");
   
@@ -315,7 +328,9 @@ void AH_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db) {
   
   /* get rdh type */
   ue->rdhType=GWEN_DB_GetIntValue(db, "rdhType", 0, -1);
-  
+  if (ue->rdhType<1)
+    ue->rdhType=1;
+
   /* read supported TAN methods */
   for (i=0; i<AH_USER_MAX_TANMETHODS; i++)
     ue->tanMethodList[i]=-1;
@@ -332,6 +347,10 @@ void AH_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db) {
   }
   
   ue->selectedTanMethod=GWEN_DB_GetIntValue(db, "selectedTanMethod", 0, 0);
+
+  /* read some settings */
+  ue->maxTransfersPerJob=GWEN_DB_GetIntValue(db, "maxTransfersPerJob", 0, AH_USER_MAX_TRANSFERS_PER_JOB);
+  ue->maxDebitNotesPerJob=GWEN_DB_GetIntValue(db, "maxDebitNotesPerJob", 0, AH_USER_MAX_DEBITNOTES_PER_JOB);
 }
 
 
@@ -441,6 +460,15 @@ void AH_User_toDb(AB_USER *u, GWEN_DB_NODE *db) {
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 		      "selectedTanMethod",
 		      ue->selectedTanMethod);
+
+  /* store some settings */
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		      "maxTransfersPerJob",
+		      ue->maxTransfersPerJob);
+  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+		      "maxDebitNotesPerJob",
+		      ue->maxDebitNotesPerJob);
+
 }
 
 
@@ -628,8 +656,9 @@ void AH_User_SetUpd(AB_USER *u, GWEN_DB_NODE *n){
 
   if (ue->dbUpd)
     GWEN_DB_Group_free(ue->dbUpd);
-  if (n)
+  if (n) {
     ue->dbUpd=GWEN_DB_Group_dup(n);
+  }
   else
     ue->dbUpd=GWEN_DB_Group_new("upd");
 }
@@ -1563,7 +1592,6 @@ void AH_User_SetSelectedTanMethod(AB_USER *u, int i) {
 
 void AH_User_LoadTanMethods(AB_USER *u) {
   AH_USER *ue;
-  AH_JOB *jTan;
 
   assert(u);
   ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
@@ -1571,40 +1599,44 @@ void AH_User_LoadTanMethods(AB_USER *u) {
 
   AH_TanMethod_List_Clear(ue->tanMethodDescriptions);
 
-  jTan=AH_Job_Tan_new(u, 1);
-  if (!jTan) {
-    DBG_WARN(AQHBCI_LOGDOMAIN, "Job HKTAN not available");
-  }
-  else {
-    GWEN_DB_NODE *db;
-    GWEN_DB_NODE *dbT;
+  if (ue->cryptMode==AH_CryptMode_Pintan) {
+    AH_JOB *jTan;
 
-    db=AH_Job_GetParams(jTan);
-    assert(db);
-
-    dbT=GWEN_DB_FindFirstGroup(db, "tanMethod");
-    if (!dbT) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN, "No tanmethod found");
+    jTan=AH_Job_Tan_new(u, 1);
+    if (!jTan) {
+      DBG_WARN(AQHBCI_LOGDOMAIN, "Job HKTAN not available");
     }
-    while(dbT) {
-      AH_TAN_METHOD *tm;
-
-      tm=AH_TanMethod_fromDb(dbT);
-      if (tm) {
-	DBG_INFO(AQHBCI_LOGDOMAIN,
-		 "Adding TAN method [%s]",
-		 AH_TanMethod_GetMethodId(tm));
-	AH_TanMethod_List_Add(tm, ue->tanMethodDescriptions);
+    else {
+      GWEN_DB_NODE *db;
+      GWEN_DB_NODE *dbT;
+  
+      db=AH_Job_GetParams(jTan);
+      assert(db);
+  
+      dbT=GWEN_DB_FindFirstGroup(db, "tanMethod");
+      if (!dbT) {
+	DBG_ERROR(AQHBCI_LOGDOMAIN, "No tanmethod found");
       }
-      else {
-	DBG_WARN(AQHBCI_LOGDOMAIN, "Invalid TAN method");
-	GWEN_DB_Dump(dbT, stderr, 2);
+      while(dbT) {
+	AH_TAN_METHOD *tm;
+  
+	tm=AH_TanMethod_fromDb(dbT);
+	if (tm) {
+	  DBG_INFO(AQHBCI_LOGDOMAIN,
+		   "Adding TAN method [%s]",
+		   AH_TanMethod_GetMethodId(tm));
+	  AH_TanMethod_List_Add(tm, ue->tanMethodDescriptions);
+	}
+	else {
+	  DBG_WARN(AQHBCI_LOGDOMAIN, "Invalid TAN method");
+	  GWEN_DB_Dump(dbT, stderr, 2);
+	}
+  
+	dbT=GWEN_DB_FindNextGroup(dbT, "tanMethod");
       }
-
-      dbT=GWEN_DB_FindNextGroup(dbT, "tanMethod");
+  
+      AH_Job_free(jTan);
     }
-
-    AH_Job_free(jTan);
   }
 }
 
@@ -1623,6 +1655,52 @@ const AH_TAN_METHOD_LIST *AH_User_GetTanMethodDescriptions(const AB_USER *u) {
 
 
 
+int AH_User_GetMaxTransfersPerJob(const AB_USER *u){
+  AH_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
+  assert(ue);
+
+  return ue->maxTransfersPerJob;
+}
+
+
+
+void AH_User_SetMaxTransfersPerJob(AB_USER *u, int i){
+  AH_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
+  assert(ue);
+
+  ue->maxTransfersPerJob=i;
+}
+
+
+
+int AH_User_GetMaxDebitNotesPerJob(const AB_USER *u){
+  AH_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
+  assert(ue);
+
+  return ue->maxDebitNotesPerJob;
+}
+
+
+
+void AH_User_SetMaxDebitNotesPerJob(AB_USER *u, int i){
+  AH_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
+  assert(ue);
+
+  ue->maxDebitNotesPerJob=i;
+}
+
 
 
 
