@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: a_bankiniletter.h 764 2006-01-13 14:00:00Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -17,8 +17,6 @@
 #include "waction.h"
 #include "winfo.h"
 
-#include <gwenhywfar/crypt.h>
-
 
 class IniLetter;
 
@@ -27,7 +25,6 @@ class ActionBankIniLetter: public WizardAction {
   Q_OBJECT
 private:
   IniLetter *_iniLetterDialog;
-  GWEN_CRYPTKEY *_key;
 public:
   ActionBankIniLetter(Wizard *w);
   virtual ~ActionBankIniLetter();
