@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: a_createfile.cpp 950 2006-02-22 19:39:02Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -19,6 +19,7 @@
 
 #include <qbanking/qbanking.h>
 #include <aqhbci/provider.h>
+#include <aqbanking/banking_be.h>
 #include <gwenhywfar/debug.h>
 
 #include <unistd.h>
@@ -51,7 +52,7 @@ bool ActionCreateFile::apply() {
   std::string fname;
   WizardInfo *wInfo;
   AB_PROVIDER *pro;
-  AH_MEDIUM *m;
+  GWEN_CRYPT_TOKEN *ct;
   int rv;
 
   if (!ActionSelectFile::apply())
@@ -66,27 +67,28 @@ bool ActionCreateFile::apply() {
   pro=wInfo->getProvider();
   assert(pro);
 
-  m=AH_Provider_FindMedium(pro, AQHBCI_A_CREATEFILE_CT_TYPE, fname.c_str());
-  if (m) {
-    DBG_ERROR(0, "Medium is already listed");
-    return false;
-  }
+  rv=AB_Banking_GetCryptToken(AB_Provider_GetBanking(pro),
+			      wInfo->getMediumType().c_str(),
+			      wInfo->getMediumName().c_str(),
+			      &ct);
 
-  m=AH_Provider_MediumFactory(pro,
-                              AQHBCI_A_CREATEFILE_CT_TYPE, 0,
-                              fname.c_str());
-  assert(m);
-
-  rv=AH_Medium_Create(m);
   if (rv) {
-    DBG_ERROR(0, "Could not create medium (%d)", rv);
-    AH_Medium_free(m);
+    DBG_ERROR(0, "Error creating CryptToken object (%d)", rv);
     return false;
   }
 
-  wInfo->setMedium(m);
+  assert(ct);
+
+  rv=GWEN_Crypt_Token_Create(ct, 0);
+  if (rv) {
+    DBG_ERROR(0, "Error creating CryptToken (%d)", rv);
+    AB_Banking_ClearCryptTokenList(AB_Provider_GetBanking(pro), 0);
+    return false;
+  }
+
+  wInfo->setToken(ct);
   wInfo->addFlags(WIZARDINFO_FLAGS_MEDIUM_CREATED |
-                  WIZARDINFO_FLAGS_MEDIUM_FILE_CREATED);
+		  WIZARDINFO_FLAGS_MEDIUM_FILE_CREATED);
 
   return true;
 }
@@ -96,8 +98,8 @@ bool ActionCreateFile::apply() {
 bool ActionCreateFile::undo() {
   WizardInfo *wInfo;
   AB_PROVIDER *pro;
-  AH_MEDIUM *m;
   std::string fname;
+  GWEN_CRYPT_TOKEN *ct;
 
   wInfo=getWizard()->getWizardInfo();
   assert(wInfo);
@@ -108,13 +110,13 @@ bool ActionCreateFile::undo() {
   if (fname.empty())
     return true;
 
-  m=wInfo->getMedium();
-  if (m) {
+  ct=wInfo->getToken();
+  if (ct) {
     if (wInfo->getFlags() & WIZARDINFO_FLAGS_MEDIUM_CREATED) {
-      AH_Medium_free(m);
+      AB_Banking_ClearCryptTokenList(AB_Provider_GetBanking(pro), 0);
       wInfo->subFlags(WIZARDINFO_FLAGS_MEDIUM_CREATED);
     }
-    wInfo->setMedium(0);
+    wInfo->setToken(NULL);
     unlink(fname.c_str());
   }
 
