@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: a_edituser.cpp,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: a_edituser.cpp,v 1.3 2006/01/13 14:00:00 cstim Exp $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
