@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: editctuser.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: editctuser.h,v 1.3 2006/02/22 19:39:02 aquamaniac Exp $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -28,10 +28,11 @@ private:
   WizardInfo *_wInfo;
   AB_BANKINFO *_bankInfo;
   bool _dataIsOk;
+  uint32_t _idList[32];
+  uint32_t _idCount;
 
   QString _getServerAddr() const;
-  AH_CRYPT_MODE _getCryptMode(AH_MEDIUM *m, int idx);
-  void _fromContext(int i);
+  void _fromContext(int i, bool overwrite=true);
 
   bool _checkStringSanity(const char *s);
 
@@ -54,6 +55,7 @@ public slots:
   void slotBankCodeChanged(const QString&);
   void slotBankCodeClicked();
   void slotContextActivated(int i);
+  void slotSpecialToggled(bool on);
 
 };
 
