@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: wizard.h 764 2006-01-13 14:00:00Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -54,7 +54,7 @@ public:
   void setNextEnabled(WizardAction *a, bool b);
   void setBackEnabled(WizardAction *a, bool b);
 
-  void log(AB_BANKING_LOGLEVEL level, const QString &s);
+  void log(GWEN_LOGGER_LEVEL level, const QString &s);
   void setDescription(const QString &s);
 
   QWidget *getWidgetAsParent();
