@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: dtaus_p.h 120 2004-09-17 09:08:57Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -21,21 +18,40 @@
 
 typedef struct AH_IMEXPORTER_DTAUS AH_IMEXPORTER_DTAUS;
 struct AH_IMEXPORTER_DTAUS {
-  GWEN_DB_NODE *dbData;
   GWEN_DBIO *dbio;
 };
 
 
-AB_IMEXPORTER* dtaus_factory(AB_BANKING *ab, GWEN_DB_NODE *db);
-void AH_ImExporterDTAUS_FreeData(void *bp, void *p);
+AQBANKING_EXPORT
+GWEN_PLUGIN *imexporters_dtaus_factory(GWEN_PLUGIN_MANAGER *pm,
+				       const char *name,
+				       const char *fileName);
 
+static
+AB_IMEXPORTER *AB_Plugin_ImExporterDTAUS_Factory(GWEN_PLUGIN *pl,
+						 AB_BANKING *ab);
+
+static
+void GWENHYWFAR_CB AH_ImExporterDTAUS_FreeData(void *bp, void *p);
+
+static
 int AH_ImExporterDTAUS_Import(AB_IMEXPORTER *ie,
                               AB_IMEXPORTER_CONTEXT *ctx,
-                              GWEN_BUFFEREDIO *bio,
-                              GWEN_DB_NODE *params);
+                              GWEN_IO_LAYER *io,
+			      GWEN_DB_NODE *params,
+			      uint32_t guiid);
 
-int AH_ImExporterDTAUS_CheckFile(AB_IMEXPORTER *ie, const char *fname);
+static
+int AH_ImExporterDTAUS_Export(AB_IMEXPORTER *ie,
+			      AB_IMEXPORTER_CONTEXT *ctx,
+			      GWEN_IO_LAYER *io,
+			      GWEN_DB_NODE *params,
+			      uint32_t guiid);
 
+static
+int AH_ImExporterDTAUS_CheckFile(AB_IMEXPORTER *ie, const char *fname, uint32_t guiid);
+
+static
 int AH_ImExporterDTAUS__ImportFromGroup(AB_IMEXPORTER_CONTEXT *ctx,
                                         GWEN_DB_NODE *db,
                                         GWEN_DB_NODE *dbParams);
