@@ -31,8 +31,7 @@ GWEN_PLUGIN *imexporters_ofx_factory(GWEN_PLUGIN_MANAGER *pm,
 
 static
 AB_IMEXPORTER *AB_Plugin_ImExporterOFX_Factory(GWEN_PLUGIN *pl,
-					       AB_BANKING *ab,
-					       GWEN_DB_NODE *db);
+					       AB_BANKING *ab);
 
 static
 void GWENHYWFAR_CB AH_ImExporterOFX_FreeData(void *bp, void *p);
