@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Fri Apr 02 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004,2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -36,6 +33,7 @@
 
 
 GWEN_LIST_FUNCTIONS(AHB_SWIFT_TAG, AHB_SWIFT_Tag);
+GWEN_LIST_FUNCTIONS(AHB_SWIFT_SUBTAG, AHB_SWIFT_SubTag);
 
 
 
@@ -66,16 +64,14 @@ int AHB_SWIFT_Condense(char *buffer, int keepMultipleBlanks) {
     while(*src) {
       if (isspace(*src) && (*src!=10)) {
 	if (!lastWasBlank) {
-	  *dst=' ';
-	  dst++;
+	  *(dst++)=' ';
 	  lastWasBlank=1;
 	}
       }
       else {
 	lastWasBlank=0;
 	if (*src!=10) {
-	  *dst=*src;
-	  dst++;
+	  *(dst++)=*src;
 	}
       }
       src++;
@@ -131,6 +127,136 @@ const char *AHB_SWIFT_Tag_GetData(const AHB_SWIFT_TAG *tg){
 
 
 
+AHB_SWIFT_SUBTAG *AHB_SWIFT_SubTag_new(int id, const char *content, int clen) {
+  AHB_SWIFT_SUBTAG *stg;
+
+  assert(content);
+  GWEN_NEW_OBJECT(AHB_SWIFT_SUBTAG, stg);
+  GWEN_LIST_INIT(AHB_SWIFT_SUBTAG, stg);
+  stg->id=id;
+  if (clen==-1)
+    clen=strlen(content);
+  stg->content=(char*)malloc(clen+1);
+  memmove(stg->content, content, clen);
+  stg->content[clen]=0;
+  return stg;
+}
+
+
+
+void AHB_SWIFT_SubTag_free(AHB_SWIFT_SUBTAG *stg) {
+  if (stg) {
+    GWEN_LIST_FINI(AHB_SWIFT_SUBTAG, stg);
+    free(stg->content);
+    GWEN_FREE_OBJECT(stg);
+  }
+}
+
+
+
+int AHB_SWIFT_SubTag_GetId(const AHB_SWIFT_SUBTAG *stg){
+  assert(stg);
+  return stg->id;
+}
+
+
+
+const char *AHB_SWIFT_SubTag_GetData(const AHB_SWIFT_SUBTAG *stg){
+  assert(stg);
+  return stg->content;
+}
+
+
+
+AHB_SWIFT_SUBTAG *AHB_SWIFT_FindSubTagById(const AHB_SWIFT_SUBTAG_LIST *stlist, int id) {
+  AHB_SWIFT_SUBTAG *stg;
+
+  stg=AHB_SWIFT_SubTag_List_First(stlist);
+  while(stg) {
+    if (stg->id==id)
+      break;
+    stg=AHB_SWIFT_SubTag_List_Next(stg);
+  }
+
+  return stg;
+}
+
+
+
+void AHB_SWIFT_SubTag_Condense(AHB_SWIFT_SUBTAG *stg, int keepMultipleBlanks) {
+  assert(stg);
+  AHB_SWIFT_Condense(stg->content, keepMultipleBlanks);
+}
+
+
+
+int AHB_SWIFT_GetNextSubTag(const char **sptr, AHB_SWIFT_SUBTAG **tptr) {
+  const char *s;
+  int id=0;
+  int nextId=0;
+  const char *content=NULL;
+  AHB_SWIFT_SUBTAG *stg;
+
+  s=*sptr;
+  if (*s=='?') {
+    /* we check for >3 because empty fields are also treated as "no subtag" */
+    if (strlen(s)>3 && isdigit(s[1]) && isdigit(s[2])) {
+      id=((s[1]-'0')*10)+(s[2]-'0');
+      s+=3;
+    }
+  }
+  content=s;
+
+  /* find end of content */
+  for (;;) {
+    while(*s && *s!='?')
+      s++;
+    if (*s=='?' && strlen(s)>3 && isdigit(s[1]) && isdigit(s[2])) {
+      nextId=((s[1]-'0')*10)+(s[2]-'0');
+      /* TODO: check nextId */
+      /* s is the beginning of a new subtag, so the end has been found */
+      break;
+    }
+    else if (*s)
+      /* not the beginning of a new tag, continue */
+      s++;
+    else
+      /* end of string, also end of content */
+      break;
+  }
+
+  /* create subtag */
+  stg=AHB_SWIFT_SubTag_new(id, content, s-content);
+
+  /* update return pointers */
+  *tptr=stg;
+  *sptr=s;
+  return 0;
+}
+
+
+
+int AHB_SWIFT_ParseSubTags(const char *s, AHB_SWIFT_SUBTAG_LIST *stlist, int keepMultipleBlanks) {
+  while(*s) {
+    int rv;
+    AHB_SWIFT_SUBTAG *stg=NULL;
+
+    rv=AHB_SWIFT_GetNextSubTag(&s, &stg);
+    if (rv) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+    AHB_SWIFT_SubTag_Condense(stg, keepMultipleBlanks);
+    AHB_SWIFT_SubTag_List_Add(stg, stlist);
+  }
+
+  return 0;
+}
+
+
+
+
+
 int AHB_SWIFT_ReadLine(GWEN_FAST_BUFFER *fb,
                        char *buffer,
 		       unsigned int s){
