@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: swift940_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: swift940_l.h,v 1.2 2004/09/15 09:21:25 aquamaniac Exp $
+ cvs         : $Id$
  begin       : Fri Apr 02 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -17,11 +17,13 @@
 #include "swift_l.h"
 
 
-int AHB_SWIFT940_Import(GWEN_BUFFEREDIO *bio,
-			AHB_SWIFT_TAG_LIST *tl,
-			GWEN_TYPE_UINT32 flags,
+int AHB_SWIFT940_Import(AHB_SWIFT_TAG_LIST *tl,
 			GWEN_DB_NODE *data,
-			GWEN_DB_NODE *cfg);
+			GWEN_DB_NODE *cfg,
+			uint32_t flags,
+			uint32_t guiid,
+			int msecs);
+
 
 #endif /* AQHBCIBANK_SWIFT940_P_H */
 
